==> vss-ui-4.141.4.tgz: package/Components/HubHeader/HubHeader.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from "react";
import { BaseComponent, css } from "office-ui-fabric-react/lib/Utilities";
import { VssBreadcrumb } from "../../Components/VssBreadcrumb/VssBreadcrumb";
import { HubTitle } from "../../Components/HubHeader/HubTitle";
import { ObservableLike } from '../../Core/Observable';
import "./HubHeader.css";
var MAX_BREADCRUMB_WIDTH = '340px';
/**
 * Component that generates a standard VSTS page header.
 */
var HubHeader = /** @class */ (function (_super) {
    tslib_1.__extends(HubHeader, _super);
    function HubHeader(props) {
        var _this = _super.call(this, props) || this;
        _this.dataDidRender = function (renderedData) {
            var breadcrumbProps = _this.props.breadcrumbProps;
            var canBreadcrumbShrink = _this.state.canBreadcrumbShrink;
            if (breadcrumbProps && breadcrumbProps.onReduceData) {
                var breadcrumbData = breadcrumbProps.onReduceData(renderedData);
                if (breadcrumbData === undefined && canBreadcrumbShrink) {
                    _this.setState({ canBreadcrumbShrink: false });
                }
                else if (breadcrumbData !== undefined && !canBreadcrumbShrink) {
                    _this.setState({ canBreadcrumbShrink: true });
                }
            }
        };
        _this.onSelectionChanged = function (selection) {
            var headerItemPicker = _this.state.headerItemPicker;
            var preventDefault = false;
            if (headerItemPicker && headerItemPicker.onSelectedItemChanged) {
                preventDefault = headerItemPicker.onSelectedItemChanged(selection.selectedItems && selection.selectedItems.length > 0 ? selection.selectedItems[0] : null) === true;
                if (_this._hubBreadcrumb && _this._hubBreadcrumb.pickList) {
                    _this._hubBreadcrumb.pickList.closeDropdown();
                }
            }
            return preventDefault;
        };
        _this.onHeaderPickerChanged = function (headerItemPicker) {
            _this.setState({ headerItemPicker: headerItemPicker });
        };
        _this.state = {
            headerItemPicker: ObservableLike.getValue(_this.props.headerItemPicker),
            canBreadcrumbShrink: true
        };
        return _this;
    }
    HubHeader.prototype.componentWillMount = function () {
        ObservableLike.subscribe(this.props.headerItemPicker, this.onHeaderPickerChanged);
    };
    HubHeader.prototype.componentWillUnmount = function () {
        ObservableLike.unsubscribe(this.props.headerItemPicker, this.onHeaderPickerChanged);
    };
    HubHeader.prototype.componentWillReceiveProps = function (nextProps) {
        if (this.props.headerItemPicker !== nextProps.headerItemPicker) {
            this.setState({ headerItemPicker: ObservableLike.getValue(nextProps.headerItemPicker) });
            ObservableLike.unsubscribe(this.props.headerItemPicker, this.onHeaderPickerChanged);
            ObservableLike.subscribe(nextProps.headerItemPicker, this.onHeaderPickerChanged);
        }
    };
    /**
     * Gets the title (Breadcrumb control or HubTitle control, depending on whether or not breadcrumbitems were passed).
     */
    HubHeader.prototype.getTitle = function () {
        if ((this.props.breadcrumbItems && this.props.breadcrumbItems.length > 0) || this.props.headerItemPicker) {
            return this.getBreadcrumb();
        }
        else {
            if (this.props.title) {
                return (React.createElement(HubTitle, { titleText: this.props.title, iconProps: this.props.iconProps }));
            }
            else {
                console.log("Must use title or breadcrumb items + headerItemPicker");
                return null;
            }
        }
    };
    HubHeader.prototype.getBreadcrumb = function () {
        var _this = this;
        var breadcrumbItems = (this.props.breadcrumbItems) ? this.props.breadcrumbItems.slice() : [];
        var _a = this.props, maxBreadcrumbItemWidth = _a.maxBreadcrumbItemWidth, collapseBreadcrumb = _a.collapseBreadcrumb, iconProps = _a.iconProps, pickListClassName = _a.pickListClassName, pickListMinWidth = _a.pickListMinWidth, pickListMaxWidth = _a.pickListMaxWidth, pickListMaxHeight = _a.pickListMaxHeight, title = _a.title, hubBreadcrumbAriaLabel = _a.hubBreadcrumbAriaLabel, breadcrumbProps = _a.breadcrumbProps;
        var headerItemPicker = this.state.headerItemPicker;
        if (headerItemPicker && headerItemPicker.getListItem) {
            var selectedItem = headerItemPicker.selectedItem && headerItemPicker.getListItem(headerItemPicker.selectedItem);
            var selectedItemTitleText = (headerItemPicker.selectedItem && headerItemPicker.getTitleTextForItem) ?
                headerItemPicker.getTitleTextForItem(headerItemPicker.selectedItem) :
                selectedItem && selectedItem.name;
            var titleItem = {
                key: 'title-item',
                text: title ? title : selectedItemTitleText,
                leftIconProps: iconProps,
                onSelectionChanged: this.onSelectionChanged,
                itemPicker: headerItemPicker,
                ariaLabel: headerItemPicker.ariaLabel,
                isHeaderPickerItem: true
            };
            breadcrumbItems.push(titleItem);
        }
        else if (title) {
            var titleItem = {
                key: 'title-item',
                text: title,
                leftIconProps: iconProps,
            };
            breadcrumbItems.push(titleItem);
        }
        if (collapseBreadcrumb) {
            breadcrumbItems = breadcrumbItems.slice(breadcrumbItems.length - 1);
            // If breadcrumbProps is passed, make sure overflowIndex is 0 when collapseBreadcrumb
            if (breadcrumbProps) {
                breadcrumbProps.overflowIndex = 0;
            }
        }
        return React.createElement(VssBreadcrumb, tslib_1.__assign({}, breadcrumbProps, { dataDidRender: this.dataDidRender, ref: function (hubBreadcrumb) { _this._hubBreadcrumb = hubBreadcrumb; }, items: breadcrumbItems, maxItemWidth: typeof maxBreadcrumbItemWidth === 'string' ? maxBreadcrumbItemWidth : MAX_BREADCRUMB_WIDTH, pickListClassName: pickListClassName, pickListMinWidth: pickListMinWidth, pickListMaxWidth: pickListMaxWidth, pickListMaxHeight: pickListMaxHeight, ariaLabel: hubBreadcrumbAriaLabel, shouldUseFocusZone: true, presentationStyles: 8 /* dividerLink */ | 16 /* minHeight */ }));
    };
    HubHeader.prototype.render = function () {
        return (React.createElement("div", { className: css("vss-HubHeader", { "vss-HubHeader-no-shrink": !this.state.canBreadcrumbShrink }) },
            this.getTitle(),
            this.props.children));
    };
    return HubHeader;
}(BaseComponent));
export { HubHeader };

==> vss-ui-4.142.1.tgz: package/Components/HubHeader/HubHeader.js <==
import * as tslib_1 from "tslib";
import "../../FabricInit";
import * as React from "react";
import { BaseComponent, css } from "office-ui-fabric-react/lib/Utilities";
import { VssBreadcrumb } from "../../Components/VssBreadcrumb/VssBreadcrumb";
import { HubTitle } from "../../Components/HubHeader/HubTitle";
import { ObservableLike } from '../../Core/Observable';
import "./HubHeader.css";
var MAX_BREADCRUMB_WIDTH = '340px';
/**
 * Component that generates a standard VSTS page header.
 */
var HubHeader = /** @class */ (function (_super) {
    tslib_1.__extends(HubHeader, _super);
    function HubHeader(props) {
        var _this = _super.call(this, props) || this;
        _this.dataDidRender = function (renderedData, itemsWidth) {
            var _a = _this.props, breadcrumbProps = _a.breadcrumbProps, breadcrumbDataDidRender = _a.breadcrumbDataDidRender;
            var canBreadcrumbShrink = _this.state.canBreadcrumbShrink;
            if (breadcrumbProps && breadcrumbProps.onReduceData) {
                var breadcrumbData = breadcrumbProps.onReduceData(renderedData);
                if (breadcrumbData === undefined && canBreadcrumbShrink) {
                    _this.setState({ canBreadcrumbShrink: false });
                }
                else if (breadcrumbData !== undefined && !canBreadcrumbShrink) {
                    _this.setState({ canBreadcrumbShrink: true });
                }
            }
            if (breadcrumbDataDidRender) {
                breadcrumbDataDidRender(renderedData, itemsWidth);
            }
        };
        _this.onSelectionChanged = function (selection) {
            var headerItemPicker = _this.state.headerItemPicker;
            var preventDefault = false;
            if (headerItemPicker && headerItemPicker.onSelectedItemChanged) {
                preventDefault = headerItemPicker.onSelectedItemChanged(selection.selectedItems && selection.selectedItems.length > 0 ? selection.selectedItems[0] : null) === true;
                if (_this._hubBreadcrumb && _this._hubBreadcrumb.pickList) {
                    _this._hubBreadcrumb.pickList.closeDropdown();
                }
            }
            return preventDefault;
        };
        _this.onHeaderPickerChanged = function (headerItemPicker) {
            _this.setState({ headerItemPicker: headerItemPicker });
        };
        _this.state = {
            headerItemPicker: ObservableLike.getValue(_this.props.headerItemPicker),
            canBreadcrumbShrink: true
        };
        return _this;
    }
    HubHeader.prototype.componentWillMount = function () {
        ObservableLike.subscribe(this.props.headerItemPicker, this.onHeaderPickerChanged);
    };
    HubHeader.prototype.componentWillUnmount = function () {
        ObservableLike.unsubscribe(this.props.headerItemPicker, this.onHeaderPickerChanged);
    };
    HubHeader.prototype.componentWillReceiveProps = function (nextProps) {
        if (this.props.headerItemPicker !== nextProps.headerItemPicker) {
            this.setState({ headerItemPicker: ObservableLike.getValue(nextProps.headerItemPicker) });
            ObservableLike.unsubscribe(this.props.headerItemPicker, this.onHeaderPickerChanged);
            ObservableLike.subscribe(nextProps.headerItemPicker, this.onHeaderPickerChanged);
        }
    };
    /**
     * Gets the title (Breadcrumb control or HubTitle control, depending on whether or not breadcrumbitems were passed).
     */
    HubHeader.prototype.getTitle = function () {
        if ((this.props.breadcrumbItems && this.props.breadcrumbItems.length > 0) || this.props.headerItemPicker) {
            return this.getBreadcrumb();
        }
        else {
            if (this.props.title) {
                return (React.createElement(HubTitle, { titleText: this.props.title, iconProps: this.props.iconProps }));
            }
            else {
                console.log("Must use title or breadcrumb items + headerItemPicker");
                return null;
            }
        }
    };
    HubHeader.prototype.getBreadcrumb = function () {
        var _this = this;
        var breadcrumbItems = (this.props.breadcrumbItems) ? this.props.breadcrumbItems.slice() : [];
        var _a = this.props, maxBreadcrumbItemWidth = _a.maxBreadcrumbItemWidth, collapseBreadcrumb = _a.collapseBreadcrumb, iconProps = _a.iconProps, pickListClassName = _a.pickListClassName, pickListMinWidth = _a.pickListMinWidth, pickListMaxWidth = _a.pickListMaxWidth, pickListMaxHeight = _a.pickListMaxHeight, title = _a.title, hubBreadcrumbAriaLabel = _a.hubBreadcrumbAriaLabel, breadcrumbProps = _a.breadcrumbProps;
        var headerItemPicker = this.state.headerItemPicker;
        if (headerItemPicker && headerItemPicker.getListItem) {
            var selectedItem = headerItemPicker.selectedItem && headerItemPicker.getListItem(headerItemPicker.selectedItem);
            var selectedItemTitleText = (headerItemPicker.selectedItem && headerItemPicker.getTitleTextForItem) ?
                headerItemPicker.getTitleTextForItem(headerItemPicker.selectedItem) :
                selectedItem && selectedItem.name;
            var titleItem = {
                key: 'title-item',
                text: title ? title : selectedItemTitleText,
                leftIconProps: iconProps,
                onSelectionChanged: this.onSelectionChanged,
                itemPicker: headerItemPicker,
                ariaLabel: headerItemPicker.ariaLabel,
                isHeaderPickerItem: true
            };
            breadcrumbItems.push(titleItem);
        }
        else if (title) {
            var titleItem = {
                key: 'title-item',
                text: title,
                leftIconProps: iconProps,
            };
            breadcrumbItems.push(titleItem);
        }
        if (collapseBreadcrumb) {
            breadcrumbItems = breadcrumbItems.slice(breadcrumbItems.length - 1);
            // If breadcrumbProps is passed, make sure overflowIndex is 0 when collapseBreadcrumb
            if (breadcrumbProps) {
                breadcrumbProps.overflowIndex = 0;
            }
        }
        return React.createElement(VssBreadcrumb, tslib_1.__assign({}, breadcrumbProps, { dataDidRender: this.dataDidRender, ref: function (hubBreadcrumb) { _this._hubBreadcrumb = hubBreadcrumb; }, items: breadcrumbItems, maxItemWidth: typeof maxBreadcrumbItemWidth === 'string' ? maxBreadcrumbItemWidth : MAX_BREADCRUMB_WIDTH, pickListClassName: pickListClassName, pickListMinWidth: pickListMinWidth, pickListMaxWidth: pickListMaxWidth, pickListMaxHeight: pickListMaxHeight, ariaLabel: hubBreadcrumbAriaLabel, shouldUseFocusZone: true, presentationStyles: 8 /* dividerLink */ | 16 /* minHeight */ }));
    };
    HubHeader.prototype.render = function () {
        return (React.createElement("div", { className: css("vss-HubHeader", { "vss-HubHeader-no-shrink": !this.state.canBreadcrumbShrink }) },
            this.getTitle(),
            this.props.children));
    };
    return HubHeader;
}(BaseComponent));
export { HubHeader };
